import { fetch } from '@/api/index';
import { logout, getInfo } from '@/api/user'
import { getToken, setToken, removeToken } from '@/utils/auth'
import { resetRouter } from '@/router'

const getDefaultState = () => {
  return {
    token: getToken(),
    userData: {},
    name: '',
    avatar: ''
  }
}

const state = getDefaultState()

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_USERDATA: (state, data) => {
    state.userData = data
  }
}

const actions = {

  // get user info
  getInfo({ commit, state }) {
    return new Promise(async (resolve, reject) => {

      // const data = await fetch('/getUserInfo')
        // const data = {code: 200, data: {username: 'admin'}}
        const data = await fetch('/home/authList', {}, 'get')
        if (data.code == 200) {
          commit('SET_NAME', data.data.user_name)
          commit('SET_AVATAR', 'avatar')
          // commit('SET_USERDATA', data.data)
          resolve(data.data)
        } else {
          reject('error')
        }
    })
  },

  // user logout
  logout({ commit, state }) {
    return new Promise((resolve, reject) => {
      removeToken() // must remove  token  first
      resetRouter()
      commit('RESET_STATE')
      resolve()
      // logout(state.token).then(() => {
      //   removeToken() // must remove  token  first
      //   resetRouter()
      //   commit('RESET_STATE')
      //   resolve()
      // }).catch(error => {
      //   reject(error)
      // })
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      commit('RESET_STATE')
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

